@@ -17,95 +17,103 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
+// Self
 #include "Resources.h"
 #include "Resources_p.h"
-#include "resourcesadaptor.h"
 
+// Qt
 #include <QDBusConnection>
 #include <QThread>
 #include <QMutex>
 #include <QMutexLocker>
-#include <QDebug>
 
-#include <KUrl>
-#include <KWindowSystem>
-
-#include <Application.h>
-#include <Activities.h>
-
-#include <time.h>
-
-#include "common.h"
+// KDE
+#include <kwindowsystem.h>
+#include <kdbusconnectionpool.h>
 
+// Utils
 #include <utils/d_ptr_implementation.h>
 #include <utils/remove_if.h>
 
-Resources::Private::Private(Resources * parent)
-    : QThread(parent), focussedWindow(0), q(parent)
+// System
+#include <time.h>
+
+// Local
+#include "Debug.h"
+#include "Application.h"
+#include "Activities.h"
+#include "resourcesadaptor.h"
+#include "common/dbus/common.h"
+
+
+Resources::Private::Private(Resources *parent)
+    : QThread(parent)
+    , focussedWindow(0)
+    , q(parent)
 {
 }
 
 namespace {
-    EventList events;
-    QMutex events_mutex;
+EventList events;
+QMutex events_mutex;
 }
 
 void Resources::Private::run()
 {
     forever {
         // initial delay before processing the events
-        sleep(5);
+        sleep(1);
 
         EventList currentEvents;
 
         {
-            QMutexLocker locker(& events_mutex);
+            QMutexLocker locker(&events_mutex);
 
             if (events.count() == 0) {
-                // qDebug() << "No more events to process, exiting.";
                 return;
             }
 
-            currentEvents = events;
-            events.clear();
+            std::swap(currentEvents, events);
         }
 
         emit q->ProcessedResourceEvents(currentEvents);
     }
 }
 
-void Resources::Private::insertEvent(const Event & newEvent)
+void Resources::Private::insertEvent(const Event &newEvent)
 {
-    if (lastEvent == newEvent) return;
+    if (lastEvent == newEvent) {
+        return;
+    }
+
     lastEvent = newEvent;
 
     {
-        QMutexLocker locker(& events_mutex);
+        QMutexLocker locker(&events_mutex);
         events << newEvent;
     }
 
     emit q->RegisteredResourceEvent(newEvent);
 }
 
-void Resources::Private::addEvent(const QString & application, WId wid, const QString & uri,
-            int type, int reason)
+void Resources::Private::addEvent(const QString &application, WId wid,
+                                  const QString &uri, int type)
 {
-    Event newEvent(application, wid, uri, type, reason);
+    Event newEvent(application, wid, uri, type);
     addEvent(newEvent);
 }
 
-void Resources::Private::addEvent(const Event & newEvent)
+void Resources::Private::addEvent(const Event &newEvent)
 {
     // And now, for something completely delayed
     {
-        QMutexLocker locker(& events_mutex);
+        QMutexLocker locker(&events_mutex);
 
         // Deleting previously registered Accessed events if
         // the current one has the same application and uri
         if (newEvent.type != Event::Accessed) {
-            kamd::utils::remove_if(events, [&newEvent] (const Event & event) -> bool {
+            kamd::utils::remove_if(events, [&newEvent](const Event &event)->bool {
                 return
-                    event.reason      == Event::Accessed      &&
                     event.application == newEvent.application &&
                     event.uri         == newEvent.uri
                 ;
@@ -121,22 +129,20 @@ void Resources::Private::addEvent(const Event & newEvent)
     // as well.
 
     if (newEvent.wid != 0) {
-        WindowData & data = windows[newEvent.wid];
-        const KUrl & kuri(newEvent.uri);
+        WindowData &window = windows[newEvent.wid];
+        const QString &uri = newEvent.uri;
 
-        qDebug() << kuri << data.focussedResource;
-
-        data.application = newEvent.application;
+        window.application = newEvent.application;
 
         switch (newEvent.type) {
             case Event::Opened:
                 insertEvent(newEvent);
 
-                if (data.focussedResource.isEmpty()) {
+                if (window.focussedResource.isEmpty()) {
                     // This window haven't had anything focused,
                     // assuming the new document is focused
 
-                    data.focussedResource = newEvent.uri;
+                    window.focussedResource = newEvent.uri;
                     insertEvent(newEvent.deriveWithType(Event::FocussedIn));
                 }
 
@@ -144,28 +150,26 @@ void Resources::Private::addEvent(const Event & newEvent)
 
             case Event::FocussedIn:
 
-                if (!data.resources.contains(kuri)) {
+                if (!window.resources.contains(uri)) {
                     // This window did not contain this resource before,
                     // sending Opened event
 
                     insertEvent(newEvent.deriveWithType(Event::Opened));
                 }
 
-                data.focussedResource = newEvent.uri;
+                window.focussedResource = newEvent.uri;
                 insertEvent(newEvent);
 
                 break;
 
             case Event::Closed:
 
-                qDebug() << data.focussedResource << kuri;
-
-                if (data.focussedResource == kuri) {
+                if (window.focussedResource == uri) {
                     // If we are closing a document that is in focus,
                     // release focus first
 
                     insertEvent(newEvent.deriveWithType(Event::FocussedOut));
-                    data.focussedResource.clear();
+                    window.focussedResource.clear();
                 }
 
                 insertEvent(newEvent);
@@ -174,8 +178,8 @@ void Resources::Private::addEvent(const Event & newEvent)
 
             case Event::FocussedOut:
 
-                if (data.focussedResource == kuri) {
-                    data.focussedResource.clear();
+                if (window.focussedResource == uri) {
+                    window.focussedResource.clear();
                 }
 
                 insertEvent(newEvent);
@@ -185,7 +189,14 @@ void Resources::Private::addEvent(const Event & newEvent)
             default:
                 insertEvent(newEvent);
                 break;
+        }
 
+    } else {
+        // If we haven't got a window, just pass the event on,
+        // but only if it is not a focus event
+        if (newEvent.type != Event::FocussedIn
+            && newEvent.type != Event::FocussedOut) {
+            insertEvent(newEvent);
         }
     }
 
@@ -206,9 +217,9 @@ void Resources::Private::windowClosed(WId windowId)
 
     // Closing all the resources that the window registered
 
-    foreach (const KUrl & uri, windows[windowId].resources) {
+    for (const QString &uri: windows[windowId].resources) {
         q->RegisterResourceEvent(windows[windowId].application,
-                toInt(windowId), uri.url(), Event::Closed, 0);
+                                 windowId, uri, Event::Closed);
     }
 
     windows.remove(windowId);
@@ -222,44 +233,45 @@ void Resources::Private::activeWindowChanged(WId windowId)
     // The windows can do this manually, but if they are
     // SDI, we can do it on our own.
 
-    if (windowId == focussedWindow) return;
+    if (windowId == focussedWindow) {
+        return;
+    }
 
     if (windows.contains(focussedWindow)) {
-        const WindowData & data = windows[focussedWindow];
+        const WindowData &data = windows[focussedWindow];
 
         if (!data.focussedResource.isEmpty()) {
-            insertEvent(Event(data.application, focussedWindow, data.focussedResource.url(), Event::FocussedOut));
+            insertEvent(Event(data.application, focussedWindow, data.focussedResource, Event::FocussedOut));
         }
     }
 
     focussedWindow = windowId;
 
     if (windows.contains(focussedWindow)) {
-        const WindowData & data = windows[focussedWindow];
+        const WindowData &data = windows[focussedWindow];
 
         if (!data.focussedResource.isEmpty()) {
-            insertEvent(Event(data.application, windowId, data.focussedResource.url(), Event::FocussedIn));
+            insertEvent(Event(data.application, windowId, data.focussedResource, Event::FocussedIn));
         }
     }
 }
 
-
-Resources::Resources(QObject * parent)
-    : Module("resources", parent), d(this)
+Resources::Resources(QObject *parent)
+    : Module(QStringLiteral("resources"), parent)
+    , d(this)
 {
-    qRegisterMetaType < Event > ("Event");
-    qRegisterMetaType < EventList > ("EventList");
-    qRegisterMetaType < WId > ("WId");
+    qRegisterMetaType<Event>("Event");
+    qRegisterMetaType<EventList>("EventList");
+    qRegisterMetaType<WId>("WId");
 
     new ResourcesAdaptor(this);
-    QDBusConnection::sessionBus().registerObject(
-            ACTIVITY_MANAGER_OBJECT_PATH(Resources), this);
+    KDBusConnectionPool::threadConnection().registerObject(
+        KAMD_DBUS_OBJECT_PATH(Resources), this);
 
     d->connect(KWindowSystem::self(), SIGNAL(windowRemoved(WId)),
             SLOT(windowClosed(WId)));
     d->connect(KWindowSystem::self(), SIGNAL(activeWindowChanged(WId)),
             SLOT(activeWindowChanged(WId)));
-
 }
 
 Resources::~Resources()
@@ -267,69 +279,57 @@ Resources::~Resources()
 }
 
 void Resources::RegisterResourceEvent(QString application, uint _windowId,
-        const QString & uri, uint event, uint reason)
+                                      const QString &uri, uint event)
 {
-    Q_ASSERT_X(!uri.startsWith("nepomuk:"), "Resources::RegisterResourceEvent",
-            "We do not accept nepomuk URIs for resource events");
-
-    if (
-           event > Event::LastEventType
-        || reason > Event::LastEventReason
+    if (event > Event::LastEventType
         || uri.isEmpty()
-        || application.isEmpty()
-        // Dirty way to skip special web browser URIs
-        // This is up to the plugin - whether it wants it filtered out or not
-        // || uri.startsWith(QLatin1String("about:"))
-    ) return;
+        || application.isEmpty()) {
+        return;
+    }
 
-    KUrl kuri(uri);
-    WId windowId = (WId) _windowId;
+    WId windowId = (WId)_windowId;
 
-    d->addEvent(application, windowId,
-            kuri.url(), (Event::Type) event, (Event::Reason) reason);
+    d->addEvent(application, windowId, uri, (Event::Type)event);
 }
 
-
-void Resources::RegisterResourceMimeType(const QString & uri, const QString & mimetype)
+void Resources::RegisterResourceMimetype(const QString &uri, const QString &mimetype)
 {
-    if (!mimetype.isEmpty()) return;
+    if (!mimetype.isEmpty()) {
+        return;
+    }
 
-    KUrl kuri(uri);
-
-    emit RegisteredResourceMimeType(uri, mimetype);
+    emit RegisteredResourceMimetype(uri, mimetype);
 }
 
-
-void Resources::RegisterResourceTitle(const QString & uri, const QString & title)
+void Resources::RegisterResourceTitle(const QString &uri, const QString &title)
 {
     // A dirty saninty check for the title
-    if (title.length() < 3) return;
-
-    KUrl kuri(uri);
+    if (title.length() < 3) {
+        return;
+    }
 
     emit RegisteredResourceTitle(uri, title);
 }
 
-bool Resources::isFeatureOperational(const QStringList & feature) const
+bool Resources::isFeatureOperational(const QStringList &feature) const
 {
     Q_UNUSED(feature)
     return false;
 }
 
-bool Resources::isFeatureEnabled(const QStringList & feature) const
+bool Resources::isFeatureEnabled(const QStringList &feature) const
 {
     Q_UNUSED(feature)
     return false;
-
 }
 
-void Resources::setFeatureEnabled(const QStringList & feature, bool value)
+void Resources::setFeatureEnabled(const QStringList &feature, bool value)
 {
     Q_UNUSED(feature)
     Q_UNUSED(value)
 }
 
-QStringList Resources::listFeatures(const QStringList & feature) const
+QStringList Resources::listFeatures(const QStringList &feature) const
 {
     Q_UNUSED(feature)
     static QStringList features;
